@@ -45,6 +45,23 @@ is_posix = (os.name == 'posix')
 
 DEBUG = True
 
+def exception_handler(type, value, tb):
+    logging.exception("Uncaught exception: {0}".format(str(value)))
+
+
+# Install exception handler
+sys.excepthook = exception_handler
+
+
+def gittoappsurifyInit():
+    if not os.path.exists('./.testbrain'):
+        os.makedirs('./.testbrain')
+    if not os.path.exists('./.testbrain/debug'):
+        os.makedirs('./.testbrain/debug')
+
+
+gittoappsurifyInit()
+
 LOGGING_CONFIG = {
     'version': 1,
     'disable_existing_loggers': True,
@@ -57,7 +74,7 @@ LOGGING_CONFIG = {
     },
     'handlers': {
         'console': {
-            'level': 'DEBUG',
+            'level': 'INFO',
             'class': 'logging.StreamHandler',
             'formatter': 'default'
         },
@@ -65,7 +82,7 @@ LOGGING_CONFIG = {
             'level': 'DEBUG',
             'class': 'logging.handlers.RotatingFileHandler',
             'formatter': 'default',
-            'filename': './testbrain.log',
+            'filename': './.testbrain/debug.log',
             'maxBytes': 10 * 1024 * 1024,
             'backupCount': 7
         },
@@ -150,7 +167,7 @@ class BitbucketPlatform(BasePlatform):
 
 class GitHubPlatform(BasePlatform):
     PATTERNS = {
-        'https': r'https://(?P<domain>.+)/(?P<owner>.+)/(?P<repo>.+).git',
+        'https': r'https://(?P<domain>.+)/(?P<owner>.+)/(?P<repo>.+)(.git)?',
         'ssh': r'git@(?P<domain>.+):(?P<owner>.+)/(?P<repo>.+).git',
         'git': r'git://(?P<domain>.+)/(?P<owner>.+)/(?P<repo>.+).git',
     }
@@ -167,7 +184,7 @@ class GitHubPlatform(BasePlatform):
 
 class GitLabPlatform(BasePlatform):
     PATTERNS = {
-        'https': r'https://(?P<domain>.+)/(?P<owner>.+)/(?P<repo>.+).git',
+        'https': r'https://(?P<domain>.+)/(?P<owner>.+)/(?P<repo>.+)(.git)?',
         'ssh': r'git@(?P<domain>.+):(?P<owner>.+)/(?P<repo>.+).git',
         'git': r'git://(?P<domain>.+)/(?P<owner>.+)/(?P<repo>.+).git',
     }
@@ -381,6 +398,8 @@ def get_repo_name(dflt='UNKNOWN'):
         repo_name = r.repo
     except Exception as exc:
         logging.exception(exc, exc_info=True)
+    logging.debug("REPO_NAME: {}".format(repo_name))
+    repo_name = repo_name.replace(".git", "")
     return repo_name
 
 
@@ -463,8 +482,12 @@ def _parse_numstats(text):
         hsh["total"]["changes"] += insertions + deletions
         hsh["total"]["total"] += insertions + deletions
         hsh["total"]["files"] += 1
-        hsh["files"][f'{repo_name}/' + filename.strip()] = {"filename": f'{repo_name}/' + filename.strip(), "additions": insertions, "deletions": deletions,
-                                          "changes": insertions + deletions}
+        hsh["files"][filename.strip()] = {
+            "filename": filename.strip(),
+            "additions": insertions,
+            "deletions": deletions,
+            "changes": insertions + deletions
+        }
     return (hsh["total"], hsh["files"])
 
 
@@ -527,12 +550,12 @@ def _parse_stats(text):
             status = "renamed"
 
         diff = dict(
-            filename=f'{repo_name}/' + filename if filename else filename,
-            previous_filename=f'{repo_name}/' + previous_filename if previous_filename else previous_filename,
+            filename=filename if filename else filename,
+            previous_filename=previous_filename if previous_filename else previous_filename,
             sha=sha,
             status=status,
-            a_path=f'{repo_name}/' + a_path if a_path else a_path,
-            b_path=f'{repo_name}/' + b_path if b_path else b_path,
+            a_path=a_path if a_path else a_path,
+            b_path=b_path if b_path else b_path,
             a_blob_id=a_blob_id,
             a_blob=a_blob, b_blob_id=b_blob_id, b_blob=b_blob,
             a_mode=old_mode, b_mode=new_mode, new_file=new_file,
@@ -540,7 +563,7 @@ def _parse_stats(text):
             change_type=change_type, score=score, patch=""
         )
 
-        diffs[f'{repo_name}/' + filename if filename else filename] = diff
+        diffs[filename if filename else filename] = diff
 
     return diffs
 
@@ -595,12 +618,12 @@ def _parse_patch(text):
             status = "modified"
 
         diff = dict(
-            filename=f'{repo_name}/' + filename if filename else filename,
-            previous_filename=f'{repo_name}/' + previous_filename if previous_filename else previous_filename,
+            filename=filename if filename else filename,
+            previous_filename=previous_filename if previous_filename else previous_filename,
             sha=sha,
             status=status,
-            a_path=f'{repo_name}/' + a_path if a_path else a_path,
-            b_path=f'{repo_name}/' + b_path if b_path else b_path,
+            a_path=a_path if a_path else a_path,
+            b_path=b_path if b_path else b_path,
             a_blob_id=a_blob_id,
             a_blob=a_blob, b_blob_id=b_blob_id, b_blob=b_blob,
             a_mode=a_mode and a_mode,
@@ -640,8 +663,8 @@ def execute(commandLine):
     if error:
         process.kill()
         if DEBUG:
-            logging.error("Execution '{}'".format(repr(commandLine)))
-            logging.error("with error '{}'".format(error))
+            logging.debug("Execution '{}'".format(repr(commandLine)))
+            logging.debug("with error '{}'".format(error))
         raise Exception(error)
     return out
 
@@ -674,10 +697,10 @@ def request(url, token, data, event):
         resp = session.post(url=url, data=data, headers=headers, verify=False, allow_redirects=True)
         result = (resp.status_code, resp.reason)
         if resp.status_code == 401:
-            logging.error('Could not verify, please check it and try again.')
+            logging.debug('Could not verify, please check it and try again.')
             sys.exit(1)
     except Exception as e:
-        logging.error('Can\'t not get a connection to the server, please check your url try again.')
+        logging.debug('Can\'t not get a connection to the server, please check your url try again.')
         result = (None, None)
     return result
 
@@ -692,10 +715,10 @@ def get_project_id(base_url, project_name, token):
         session.mount('https://', HTTPAdapter(max_retries=3))
         resp = session.get(url=url, headers=headers, verify=False, allow_redirects=True)
         if resp.status_code == 401:
-            logging.error('Could not verify your token, please check it and try again.')
+            logging.debug('Could not verify your token, please check it and try again.')
             sys.exit(1)
     except Exception as e:
-        logging.error('Can\'t not get a connection to the server, please check your url or token and try again.')
+        logging.debug('Can\'t not get a connection to the server, please check your url or token and try again.')
         sys.exit(1)
     return resp.text
 
@@ -747,7 +770,7 @@ def get_file_tree():
         subdirs[:] = [sub for sub in subdirs if sub not in exclude]
         for name in files:
             file_path = os.path.join(path, name).lstrip('.').lstrip('/').lstrip('\\')
-            repo_file_path = f'{repo_name}/' + file_path
+            repo_file_path = file_path
             files_paths.append(repo_file_path)
     return files_paths
 
@@ -1099,15 +1122,11 @@ def performPush(url, token, start, number, branch, blame, repo_name=''):
         commits.append(commit)
     file_tree = get_file_tree()
     data = wrap_push_event(ref=branch, commits=commits, file_tree=file_tree, repo_name=repo_name)
-    # with open('./data.txt', 'w') as f:
-    #     f.write(data)
-    if debug:
-        if not os.path.exists('./testbrain-debug'):
-            os.makedirs('./testbrain-debug')
-        current_time = datetime.datetime.now(datetime.timezone.utc).astimezone().strftime('%Y-%m-%dT')
-        with open(f'./testbrain-debug/{current_time}.json', 'w') as f:
-            f.write(data)
+    current_time = datetime.datetime.now(datetime.timezone.utc).astimezone().strftime('%Y-%m-%dT')
+    with open(f'./.testbrain/debug/{current_time}.json', 'w') as f:
+        f.write(data)
     status_code, content = request(url, token, data, event='push')
+    logging.info("Data has been sent with status_code {}".format(status_code))
 
 parser = argparse.ArgumentParser(description='Sync a number of commits before a specific commit')
 
@@ -1157,18 +1176,22 @@ if 'project_id' in project_id_data:
     project_id = project_id_data['project_id']
     url = base_url + '/api/ssh_v2/hook/{}/'.format(project_id)
 elif 'error' in project_id_data:
-    logging.error('Project not found')
+    logging.debug('Project not found')
     sys.exit(1)
 
 
 def gittoappsurify():
     logging.info('Started syncing commits to {}'.format(base_url))
-    performPush(url=url, token=token, start=start, number=number, branch=branch, blame=blame, repo_name=repo_name)
+    performPush(url=url, token=token, start=start, number=number, branch=branch, blame=blame, repo_name=REPOSITORY_NAME)
     logging.info('Successfully synced commits to {}'.format(base_url))
     logging.info('Start commit: {}'.format(start))
     logging.info('Number of commit(s): {}'.format(number))
-    
-#example usage gittoappsurify --url "https://demo.appsurify.com/" --project "GitScript" --token "MTU6ZW9FZUxhcXpMZU9CdGZZVmZ4U3BFM3g5MmhVcDl5ZmQzampUWEM1SWRfNA" --start "a3b8cad7c079beab89e8fba3f497fe5a1fff367d" --branch "master"
+
+
+# example usage gittoappsurify --url "https://demo.appsurify.com/" --project "GitScript"
+# --token "MTU6ZW9FZUxhcXpMZU9CdGZZVmZ4U3BFM3g5MmhVcDl5ZmQzampUWEM1SWRfNA"
+# --start "a3b8cad7c079beab89e8fba3f497fe5a1fff367d" --branch "master"
+
 
 if __name__ == '__main__':
     gittoappsurify()
